xcode

package
v2.7.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: MIT Imports: 42 Imported by: 0

Documentation

Index

Constants

const (
	NoBitriseBuildCacheFlag     = "--no-bitrise-build-cache"
	CreateXCFrameworkFlag       = "-create-xcframework"
	MsgBuildCacheDisabledByFlag = "Build cache disabled by %s flag"
	MsgArgsPassedToXcodebuild   = "Arguments passed to xcodebuild: %v"
	MsgInvocationSuccess        = "Invocation succeeded ✅ after %s"
	MsgInvocationFailed         = "Invocation failed ❌ after %s: %s"
	MsgInvocationSaved          = "Invocation saved. Visit 👉 https://app.bitrise.io/build-cache/invocations/xcode/%s"

	ErrExecutingXcode = "Error executing xcodebuild: %v"
	ErrReadConfig     = "Error reading config: %v"
)
const XCodeCacheMetadataPath = "dd-metadata.json"

Variables

var (
	ActivateXcodeSuccessful = xcelerate.ActivateXcodeSuccessful //nolint:gochecknoglobals
	AddXcelerateToPath      = xcelerate.AddXcelerateToPath      //nolint:gochecknoglobals
	ErrFmtCreateXcodeConfig = xcelerate.ErrFmtCreateXcodeConfig //nolint:gochecknoglobals
)

Re-exported constants for backward compatibility with existing tests.

Functions

func ActivateXcodeCommandFn

func ActivateXcodeCommandFn(
	ctx context.Context,
	logger log.Logger,
	osProxy utils.OsProxy,
	commandFunc utils.CommandFunc,
	encoderFactory utils.EncoderFactory,
	decoderFactory utils.DecoderFactory,
	activateParams xcelerate.Params,
	envs map[string]string,
) error

ActivateXcodeCommandFn is a backward-compatible wrapper around xcelerate.Activate. Prefer xcelerate.Activate directly.

func SaveXcodeDerivedDataFilesCmdFn

func SaveXcodeDerivedDataFilesCmdFn(ctx context.Context,
	authConfig configcommon.CacheAuthConfig,
	cacheMetadataPath,
	projectRoot,
	providedCacheKey,
	derivedDataPath,
	xcodeCachePath string,
	followSymlinks bool,
	skipSPM bool,
	logger log.Logger,
	tracker deriveddata.StepAnalyticsTracker,
	startT time.Time,
	envs map[string]string,
	commandFunc func(string, ...string) (string, error),
) (*xa.CacheOperation, error)

func StartXcodeCacheProxy

func StartXcodeCacheProxy(
	ctx context.Context,
	config xcelerate.Config,
	envProvider map[string]string,
	commandFunc configcommon.CommandFunc,
	bitriseKVClient kv_storage.KVStorageClient,
	capabilitiesClient remoteexecution.CapabilitiesClient,
	listener net.Listener,
	initialLogger log.Logger,
	loggerFactory proxy.LoggerFactory,
) error

Types

type XcelerateConfig

type XcelerateConfig interface {
	Save(logger log.Logger, os utils.OsProxy, encoderFactory utils.EncoderFactory) error
}

type XcelerateParams

type XcelerateParams struct {
	OrigArgs []string
}

type XcodeRunner

type XcodeRunner interface {
	Run(ctx context.Context, args []string) xcodeargs.RunStats
}

type XcodebuildRunner

type XcodebuildRunner struct {
	Config             xcelerate.Config
	Metadata           common.CacheConfigMetadata
	InvocationID       string
	Logger             log.Logger
	CacheLogger        log.Logger
	XcodeRunner        XcodeRunner
	ProxySessionClient session.SessionClient
	XcodeArgs          xcodeargs.XcodeArgs
	// contains filtered or unexported fields
}

XcodebuildRunner holds configuration for the xcodebuild wrapper and provides Run as its main entry point.

func (*XcodebuildRunner) Run

Run executes the xcodebuild wrapper: runs xcodebuild, collects stats, sends analytics, and registers invocation relations.

Directories

Path Synopsis

Jump to